SessionType

Enum SessionType 

pub enum SessionType {
    Outbound,
    Inbound,
    BlockRelayOnly,
}
Indicates the session type

Variants



Outbound

Representing yourself as the active party means that you are the client side



Inbound

Representing yourself as a passive recipient means that you are the server side



BlockRelayOnly

We use block-relay-only connections to help prevent against partition attacks. By not relaying transactions or addresses, these connections are harder to detect by a third party, thus helping obfuscate the network topology.

Implementations

Source

impl SessionType

pub fn is_outbound(&self) -> bool

is outbound

pub fn is_inbound(&self) -> bool

is inbound

pub fn is_block_relay_only(&self) -> bool

is block_relay_only