Module network

Module network 

Global state struct and start function

Structs

DefaultExitHandler
Default exit handle
EventHandler
Used to handle global events of tentacle, such as session open/close
NetworkController
Network controller
NetworkService
Ckb network service, use to start p2p network
NetworkState
The global shared state of the network module

Enums

TransportType
Transport type on ckb

Traits

ExitHandler
Exit trait used to notify all other module to exit