Global state struct and start function
Structs
- Default
Exit Handler - Default exit handle
- Event
Handler - Used to handle global events of tentacle, such as session open/close
- Network
Controller - Network controller
- Network
Service - Ckb network service, use to start p2p network
- Network
State - The global shared state of the network module
Enums
- Transport
Type - Transport type on ckb
Traits
- Exit
Handler - Exit trait used to notify all other module to exit